#ifndef PYTHONIC_INCLUDE_OPERATOR_DELITEM__HPP
#define PYTHONIC_INCLUDE_OPERATOR_DELITEM__HPP

#include "pythonic/include/operator_/delitem.hpp"

PYTHONIC_NS_BEGIN

namespace operator_
{

  USING_FUNCTOR(__delitem__, delitem);
}
PYTHONIC_NS_END

#endif
